@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2023 Univention GmbH
+# Copyright 2013-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -54,7 +54,7 @@ def make_parent_dir(path):
     dir_path = os.path.dirname(path)
     try:
         os.makedirs(dir_path)
-    except EnvironmentError:
+    except OSError:
         if not os.path.isdir(dir_path):
             raise
 
