@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2023 Univention GmbH
+# Copyright 2013-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,7 +31,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import getpass
 import json
@@ -91,7 +90,7 @@ class UMCModuleTranslation(umc.UMC_Module):
     def __init__(self, attrs, target_language):
         # type: (Dict[str, Any], str) -> None
         attrs['target_language'] = target_language
-        return super(UMCModuleTranslation, self).__init__(attrs)
+        super(UMCModuleTranslation, self).__init__(attrs)
 
     @property
     def python_po_files(self):
@@ -181,7 +180,7 @@ class UMCModuleTranslation(umc.UMC_Module):
         return cls(attrs, target_language)
 
 
-class SpecialCase():
+class SpecialCase:
     """
     Consumes special case definition and determines matching sets of source
     files.
@@ -259,7 +258,7 @@ class SpecialCase():
 
     def create_po_template(self, output_path=os.path.curdir):
         # type: (str) -> str
-        base, ext = os.path.splitext(os.path.join(output_path, self.new_po_path))
+        base, _ext = os.path.splitext(os.path.join(output_path, self.new_po_path))
         pot_path = '{}.pot'.format(base)
         message_catalogs.create_empty_po(self.binary_package_name, pot_path)
         partial_pot_path = '{}.pot.partial'.format(base)
@@ -271,7 +270,7 @@ class SpecialCase():
         return pot_path
 
 
-class MIMEChecker():
+class MIMEChecker:
 
     # FIXME: this is not need as mimetypes implements it already. The get()
     # method should be adjusted to first use mimetypes.guess_type() and then
