@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
 Generate gettext Portable Objects and message catalogs (gettext MO and a
@@ -8,7 +8,7 @@ Univention specific JSON-based format) from multiple source files by file type.
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2023 Univention GmbH
+# Copyright 2013-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,12 +34,11 @@ Univention specific JSON-based format) from multiple source files by file type.
 # License with the Debian GNU/Linux or Univention distribution in file
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
-from __future__ import absolute_import
 
 import os
 
 import polib
-from lxml import etree
+from lxml import etree  # noqa: S410
 
 from . import message_catalogs, umc
 
@@ -131,7 +130,7 @@ class SourceFilesHTML(SourceFileSet):
         js_paths = []  # type: List[str]
         for html_path in self.files:
             with open(html_path, 'rb') as html_file:
-                tree = etree.parse(html_file, html_parser)
+                tree = etree.parse(html_file, html_parser)  # noqa: S320
 
             for element in tree.xpath('//*[@data-i18n]'):
                 msgid = element.get('data-i18n')
